==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/imagebuilder/kotlin/inputs/DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.imagebuilder.kotlin.inputs

import com.pulumi.aws.imagebuilder.inputs.DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property repositoryName The name of the container repository where the output container image is stored. This name is prefixed by the repository location.
 * @property service The service in which this image is registered. Valid values: `ECR`.
 */
public data class
DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs(
    public val repositoryName: Output<String>,
    public val service: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.imagebuilder.inputs.DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs> {
    override fun toJava():
        com.pulumi.aws.imagebuilder.inputs.DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs =
        com.pulumi.aws.imagebuilder.inputs.DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs.builder()
            .repositoryName(repositoryName.applyValue({ args0 -> args0 }))
            .service(service.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs].
 */
@PulumiTagMarker
public class
DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgsBuilder
internal constructor() {
    private var repositoryName: Output<String>? = null

    private var service: Output<String>? = null

    /**
     * @param value The name of the container repository where the output container image is stored. This name is prefixed by the repository location.
     */
    @JvmName("kfeiiiytrhumbjsc")
    public suspend fun repositoryName(`value`: Output<String>) {
        this.repositoryName = value
    }

    /**
     * @param value The service in which this image is registered. Valid values: `ECR`.
     */
    @JvmName("tifunqlmkumhiscn")
    public suspend fun service(`value`: Output<String>) {
        this.service = value
    }

    /**
     * @param value The name of the container repository where the output container image is stored. This name is prefixed by the repository location.
     */
    @JvmName("rcngumuqrqgfnskx")
    public suspend fun repositoryName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.repositoryName = mapped
    }

    /**
     * @param value The service in which this image is registered. Valid values: `ECR`.
     */
    @JvmName("lricafoyjifuqqgy")
    public suspend fun service(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.service = mapped
    }

    internal fun build():
        DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs =
        DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs(
            repositoryName = repositoryName ?: throw PulumiNullFieldException("repositoryName"),
            service = service ?: throw PulumiNullFieldException("service"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/imagebuilder/kotlin/inputs/DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.imagebuilder.kotlin.inputs

import com.pulumi.aws.imagebuilder.inputs.DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property repositoryName The name of the container repository where the output container image is stored. This name is prefixed by the repository location.
 * @property service The service in which this image is registered. Valid values: `ECR`.
 */
public data class
DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs(
    public val repositoryName: Output<String>,
    public val service: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.imagebuilder.inputs.DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs> {
    override fun toJava(): com.pulumi.aws.imagebuilder.inputs.DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs =
        com.pulumi.aws.imagebuilder.inputs.DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs.builder()
            .repositoryName(repositoryName.applyValue({ args0 -> args0 }))
            .service(service.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs].
 */
@PulumiTagMarker
public class
DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgsBuilder
internal constructor() {
    private var repositoryName: Output<String>? = null

    private var service: Output<String>? = null

    /**
     * @param value The name of the container repository where the output container image is stored. This name is prefixed by the repository location.
     */
    @JvmName("ymtmmdxwgcovalxq")
    public suspend fun repositoryName(`value`: Output<String>) {
        this.repositoryName = value
    }

    /**
     * @param value The service in which this image is registered. Valid values: `ECR`.
     */
    @JvmName("nnvktlbmdmmrudbg")
    public suspend fun service(`value`: Output<String>) {
        this.service = value
    }

    /**
     * @param value The name of the container repository where the output container image is stored. This name is prefixed by the repository location.
     */
    @JvmName("twellcrfyiyedkhl")
    public suspend fun repositoryName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.repositoryName = mapped
    }

    /**
     * @param value The service in which this image is registered. Valid values: `ECR`.
     */
    @JvmName("kjvbwnnjgotlxlpx")
    public suspend fun service(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.service = mapped
    }

    internal fun build(): DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs =
        DistributionConfigurationDistributionContainerDistributionConfigurationTargetRepositoryArgs(
            repositoryName = repositoryName ?: throw PulumiNullFieldException("repositoryName"),
            service = service ?: throw PulumiNullFieldException("service"),
        )
}
